myGame.WakePhone.prototype = {
  preload: function() {
    // Preload images for this state
  },

  create: function() {
    // Set up audio
    myGame.setupAudio();
    myGame.sounds.phone.alarm.play();

    // Background
    this.bookshelf = this.add.sprite( 0,0, 'phoneBookshelf');

    // Phone Setup
    this.phoneGroup = game.add.group();
    this.phoneBody = this.add.sprite( 800, 660, 'phoneBody');
    this.phoneGroup.add(this.phoneBody);

    this.slideEnabled = true;

    // Phone UI
    this.phoneTime = {};
    var phoneTimeTexture;

    switch (myGame.day) {
      case 1:
      this.timeType = "school wake up";
      phoneTimeTexture = 'phoneTime1';
      break;
      case 2:
      this.timeType = "work wake up";
      phoneTimeTexture = 'phoneTime2';
      break;
      case 3:
      this.timeType = "work wake up";
      phoneTimeTexture = 'phoneTime2';
      break;
      case 4:
      this.timeType = "school wake up";
      phoneTimeTexture = 'phoneTime1';
      break;
      default:
      this.timeType = "morning vitamin";
      phoneTimeTexture = 'phoneTime3';
      break;
    }

    this.phoneTime = this.add.sprite(game.world.centerX, 450, phoneTimeTexture);
    this.phoneGroup.add(this.phoneTime);

    // Phone UI
    this.phoneBar = this.add.sprite( game.world.centerX+15, game.world.centerY + 270, 'phoneBar');
    this.phoneGroup.add(this.phoneBar);

    this.phoneCircle = this.add.sprite( game.world.centerX-121, this.phoneBar.y, 'phoneCircle');
    this.phoneCircle.scale = {x:.5, y:.5};
    this.phoneCircle.inputEnabled = true;
    this.phoneCircle.input.allowVerticalDrag = false;
    this.phoneCircle.input.enableDrag();
    this.phoneCircle.events.onDragStart.add(this.moveCircle, this);
    this.phoneCircle.events.onDragStop.add(this.stopMovingCircle, this);
    game.physics.enable(this.phoneCircle, Phaser.Physics.ARCADE);
    this.phoneGroup.add(this.phoneCircle);

    this.phoneUnlocked = false;

    // Day text
    var daysOfWeek = ['Monday', 'Tuesday', 'Wednesday', 'Thursday', 'Friday'];
    var dayTextStyle = {
      font: "24px Roboto",
      fill: '#ffffff',
      align: "center"
    }

    this.dayText = game.add.text(game.world.centerX, this.phoneTime.y + 60, daysOfWeek[myGame.day-1] + ' (Day ' + myGame.day + ' of 5)', dayTextStyle);
    this.dayText.alpha = 0.5;
    this.dayText.anchor.setTo(0, 0);
    this.phoneGroup.add(this.dayText);

    // Time text
    var timeTextStyle = {
      font: "24px Roboto",
      fill: '#ffffff',
      align: "center"
    }

    this.timeText = game.add.text(game.world.centerX, this.phoneBar.y - 110, 'Alarm: ' + this.timeType, timeTextStyle);
    this.timeText.anchor.setTo(0.5, 0);
    this.phoneGroup.add(this.timeText);

    // Drag text
    var dragTextStyle = {
      font: "24px Roboto",
      fill: '#ffffff',
      align: "center"
    }

    this.dragText = game.add.text(game.world.centerX, this.timeText.y + 40, "Drag circle to dismiss", dragTextStyle);
    this.dragText.anchor.setTo(0.5, 0);
    this.dragText.alpha = 0.5;
    this.phoneGroup.add(this.dragText);

    // Mask
    this.phoneMask = this.add.graphics(0, 0);
    this.phoneMask.beginFill(0xffffff);
    this.phoneMask.drawRect(game.world.centerX - 196, game.world.centerY - 298, 393, 636);
    // this.phoneGroup.add(this.phoneMask);

    // Phone Group
    this.phoneGroup.forEach(function(item){
      item.anchor.setTo(0.5, 0.5);
    }, this);

    // Declare mask
    this.phoneCircle.mask = this.phoneMask;

    // Phone ring timer
    this.timer = this.time.create(false);
    this.timer.loop(30, this.vibratePhone, this);
    this.timer.start();

    this.timerCount = 0;

    // Tween for UI circle
    this.tweenCircleScale = this.add.tween(this.phoneCircle.scale).to({ x: .55, y: .55 }, 1000).to({ x: .5, y: .5 }, 200).loop().start();
    this.tweenCircleAlpha = this.add.tween(this.phoneCircle).to({ alpha: .9 }, 1000).to({ alpha: .8 }, 100).to({ alpha: 1 }, 100).loop().start();

    // Setup quit button
    myGame.setupQuitButton(this);
  },

  update: function() {

    if (this.phoneCircle.x < game.world.centerX-121) {
      this.phoneCircle.x = game.world.centerX-121;
    } else if (this.phoneCircle.x > game.world.centerX + this.phoneBar.width/2) {
      this.phoneCircle.x = game.world.centerX + this.phoneBar.width/2;

      if (!this.phoneUnlocked) {
        this.continue();
      }
    }
  },
  moveCircle: function(circle, pointer) {
    if (this.slideEnabled && circle.x >= game.world.centerX-121 && circle.x <= game.world.centerX + this.phoneBar.width/2) {
      // circle.body.moves = false;
      circle.x = pointer.x;
      this.timer.destroy();
      this.tweenCircleScale.stop();
      this.tweenCircleAlpha.stop();
      this.phoneCircle.alpha = 1;
      this.add.tween(this.phoneCircle.scale).to({ x:.5, y:.5 }, 200).start();
    }
  },
  stopMovingCircle: function(circle, pointer) {
    if (this.slideEnabled && circle.x >= game.world.centerX-121 && circle.x <= game.world.centerX + this.phoneBar.width/2) {
      circle.body.moves = true;
      circle.body.velocity.x = 500;
    }
  },
  continue: function() {
    myGame.sounds.phone.alarm.stop();
    this.phoneGroup.forEach(function(item){
      item.angle = 0;
    }, this);
    this.add.tween(this.phoneCircle.scale).to({ x:11, y:11 }, 500).start();
    this.add.tween(this.phoneBar.scale).to({ y:0 }, 200).start();
    this.add.tween(this.dayText).to({ alpha:0 }, 300).to({ alpha:0}, 200).to({ alpha:1}, 500).start();
    this.slideEnabled = false;

    this.time.events.add(Phaser.Timer.SECOND * .500, function(){
      this.dayText.setText('Good morning!');
      this.dayText.fill = '#333333';
      this.dayText.fontSize = 32;
    }, this);

    this.time.events.add(Phaser.Timer.SECOND * 2, function(){
      this.state.start('Wake');
    }, this);
  },
  vibratePhone: function() {
    this.timerCount++;
    var totalVibrations = 20;
    var phoneAngle = game.rnd.integerInRange(-10,10)/8;

    if (this.timerCount < totalVibrations) {
      this.phoneGroup.forEach(function(item){
        item.angle = phoneAngle;
      }, this);
    } else if (this.timerCount < totalVibrations*4) {
      this.phoneGroup.forEach(function(item){
        item.angle = 0;
      }, this);
    } else {
      this.timerCount = 0;
    }
  }
}
